@@ -92,7 +92,7 @@ n.write_to_file(filename="output.nex", interleave=True, charblock=True)
 
 """
 __author__ = 'Simon Greenhill <simon@simon.net.nz>'
-__version__ = "1.61"
+__version__ = "1.63"
 PACKAGE_NAME = "python-nexus"
 PACKAGE_VERSION = __version__
 VERSION = __version__
@@ -132,6 +132,7 @@ from nexus.reader import NexusReader
 from nexus.writer import NexusWriter
 from nexus import handlers
 from nexus.exceptions import NexusFormatException
+from nexus import bin
 from nexus import tools
 
-__all__ = ["NexusReader", "NexusWriter", "NexusFormatException", "handlers", "tools"]
+__all__ = ["NexusReader", "NexusWriter", "NexusFormatException", "handlers", "tools", "bin"]
