@@ -104,9 +104,11 @@ class NexusReader(object):
 
             # check if we're ending a block
             if END_PATTERN.search(line):
+                if block:
+                    store[block].append(line)
                 block = None
 
-            if block is not None:
+            if block:
                 store[block].append(line)
         self.raw_blocks = store
         self._do_blocks()
@@ -121,6 +123,9 @@ class NexusReader(object):
         out = ["#NEXUS\n"]
         for block in self.blocks:
             out.append(self.blocks[block].write())
+            # empty line after block if needed
+            if len(self.blocks) > 1:
+                out.append("\n")
         return "\n".join(out)
 
     def write_to_file(self, filename):
